@@ -44,7 +44,7 @@ pub struct DtnAddress(String);
 
 impl DtnAddress {
     pub fn new(node: &str, service: &str) -> DtnAddress {
-        DtnAddress(format!("{}/{}", node, service))
+        DtnAddress(format!("//{}/{}", node, service))
     }
     pub fn node_name(&self) -> &str {
         self.0
@@ -53,11 +53,23 @@ impl DtnAddress {
             .expect("invalid internal dtn address format")
     }
     pub fn service_name(&self) -> Option<&str> {
-        self.0.split('/').nth(3)
+        match self.0.splitn(4, '/').nth(3) {
+            Some(s) => {
+                if !s.is_empty() {
+                    Some(s)
+                } else {
+                    None
+                }
+            }
+            None => None,
+        }
     }
     pub fn is_non_singleton(&self) -> bool {
         self.service_name().unwrap_or_default().starts_with('~')
     }
+    pub fn is_singleton(&self) -> bool {
+        !self.service_name().unwrap_or_default().starts_with('~')
+    }
 }
 impl fmt::Display for DtnAddress {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
@@ -209,10 +221,18 @@ impl EndpointID {
     /// include an application agents endpoint, e.g., `dtn://node1/endpoint1`
     /// or for non-singletons `dtn://group1/~endpoint1`
     pub fn with_dtn(host_with_endpoint: &str) -> Result<EndpointID, EndpointIdError> {
-        let eid = EndpointID::Dtn(
-            ENDPOINT_URI_SCHEME_DTN,
-            DtnAddress(host_with_endpoint.to_owned()),
-        );
+        let host_string = if host_with_endpoint.starts_with("//") {
+            host_with_endpoint.to_owned()
+        } else {
+            format!("//{}", host_with_endpoint)
+        };
+        let host_string = if host_string[2..].contains('/') {
+            host_string
+        } else {
+            // add trailing slash for node IDs
+            format!("{}/", host_string)
+        };
+        let eid = EndpointID::Dtn(ENDPOINT_URI_SCHEME_DTN, DtnAddress(host_string));
         if let Err(err) = eid.validate() {
             Err(err)
         } else {
@@ -424,11 +444,8 @@ impl TryFrom<String> for EndpointID {
                 if ssp == "//none" {
                     return Err(EndpointIdError::NoneNotValidHost);
                 }
-                if ssp.ends_with('/') {
-                    EndpointID::with_dtn(&ssp[0..items[1].len() - 1])
-                } else {
-                    EndpointID::with_dtn(ssp)
-                }
+
+                EndpointID::with_dtn(ssp)
             }
             "ipn" => {
                 let fields: Vec<&str> = items[1].split('.').collect();
@@ -463,18 +480,19 @@ mod tests {
     use super::*;
     use test_case::test_case;
 
-    #[test_case("node1")]
-    #[test_case("node1/incoming")]
-    fn create_with_dtn_tests(input: &str) {
-        assert_eq!(
+    #[test_case("node1" => EndpointID::Dtn(ENDPOINT_URI_SCHEME_DTN, DtnAddress("//node1/".into())))]
+    #[test_case("node1/incoming" => EndpointID::Dtn(ENDPOINT_URI_SCHEME_DTN, DtnAddress("//node1/incoming".into())))]
+    fn create_with_dtn_tests(input: &str) -> EndpointID {
+        /*assert_eq!(
             EndpointID::with_dtn(input).unwrap(),
-            EndpointID::Dtn(ENDPOINT_URI_SCHEME_DTN, DtnAddress(input.to_string()))
-        );
+            EndpointID::Dtn(ENDPOINT_URI_SCHEME_DTN, DtnAddress(format!("//{}", input)))
+        );*/
+        EndpointID::with_dtn(input).unwrap()
     }
 
     #[test_case("dtn://n1/incoming" => "dtn://n1/incoming" ; "when using fully qualified dtn endpoint")]
-    #[test_case("dtn://n1/incoming/" => "dtn://n1/incoming" ; "when containing tail slash")]
-    #[test_case("dtn://n1/" => "dtn://n1" ; "when providing node eid")]
+    #[test_case("dtn://n1/incoming/" => "dtn://n1/incoming/" ; "when containing tail slash")]
+    #[test_case("dtn://n1/" => "dtn://n1/" ; "when providing node eid")]
     #[test_case("dtn:n1/incoming" => panics "" ; "when skipping double slash for dtn")]
     #[test_case("dtn//n1/incoming" => panics "" ; "when missing URL scheme separator")]
     #[test_case("n1/incoming" => panics "" ; "when missing URL scheme")]
@@ -511,9 +529,21 @@ mod tests {
     #[test_case("ipn:1.0".try_into().unwrap() => Some("1".to_string()))]
     #[test_case("dtn://node1/incoming".try_into().unwrap() => Some("node1".to_string()))]
     #[test_case("dtn://node1".try_into().unwrap() => Some("node1".to_string()))]
+    #[test_case("dtn://home_net/~tele/sensors/temperature".try_into().unwrap() => Some("home_net".to_string()))]
     fn node_part_tests(eid: EndpointID) -> Option<String> {
         eid.node()
     }
+
+    #[test_case("dtn://node1/incoming".try_into().unwrap() => Some("incoming".to_string()))]
+    #[test_case("dtn://node1".try_into().unwrap() => None)]
+    #[test_case("dtn://node_group/~mail".try_into().unwrap() => Some("~mail".to_string()))]
+    #[test_case("dtn://home_net/~tele/sensors/temperature".try_into().unwrap() => Some("~tele/sensors/temperature".to_string()))]
+    #[test_case("ipn:23.42".try_into().unwrap() => Some("42".to_string()))]
+    #[test_case("ipn:23.0".try_into().unwrap() => None)]
+    fn service_part_tests(eid: EndpointID) -> Option<String> {
+        eid.service_name()
+    }
+
     #[test_case("dtn:none".try_into().unwrap() ; "when using none endpoint")]
     #[test_case("ipn:23.42".try_into().unwrap() ; "when using ipn address")]
     #[test_case("dtn://node1/incoming".try_into().unwrap() ; "when using dtn address")]
